@@ -29,7 +29,7 @@ quiet=FALSE,
 ...
 )
 {
-checkFile(c(file1,file2), call.=FALSE)
+checkFile(c(file1,file2))
 f1 <- readLines(file1, ...)
 f2 <- readLines(file2, ...)
 # truncate:
